==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/vi/admin/statuslabels/message.php <==
<?php

return array(

    'does_not_exist' => 'Nhãn Trạng thái không tồn tại.',
    'assoc_assets'	 => 'Nhãn Trạng thái này hiện được liên kết với ít nhất một Tài sản và không thể bị xóa. Vui lòng cập nhật nội dung của bạn để không tham khảo trạng thái này nữa và thử lại.',


    'create' => array(
        'error'   => 'Nhãn trạng thái không được tạo, vui lòng thử lại.',
        'success' => 'Nhãn trạng thái được tạo thành công.'
    ),

    'update' => array(
        'error'   => 'Nhãn Tình trạng không được cập nhật, xin vui lòng thử lại',
        'success' => 'Nhãn trạng thái được tạo thành công.'
    ),

    'delete' => array(
        'confirm'   => 'Bạn có chắc bạn muốn xóa nhãn tình trạng này?',
        'error'   => 'Đã xảy ra sự cố khi xóa Nhãn trạng thái. Vui lòng thử lại.',
        'success' => 'Nhãn Trạng thái đã bị xóa thành công.'
    ),

    'help' => array(
        'undeployable'   => 'Những tài sản này không thể gán cho bất cứ ai.',
        'deployable'   => 'Những tài sản này có thể được kiểm tra. Khi được chỉ định, họ sẽ giả sử trạng thái meta là <i class="fa fa-circle text-blue"></i> <strong>Doanh tác</strong>.',
        'archived'   => 'Không thể kiểm tra các tài sản này và sẽ chỉ hiển thị trong chế độ xem Thư mục lưu trữ. Điều này hữu ích cho việc giữ lại thông tin về tài sản cho mục đích lịch sử ngân sách nhưng giữ chúng khỏi danh mục tài sản hằng ngày.',
        'pending'   => 'Những tài sản này không thể được gán cho bất cứ ai, thường được sử dụng cho các vật phẩm được sửa chữa, nhưng dự kiến ​​sẽ quay trở lại lưu thông.',
    ),

);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/vi/admin/statuslabels/message.php <==
<?php

return [

    'does_not_exist' => 'Nhãn Trạng thái không tồn tại.',
    'assoc_assets'	 => 'Nhãn Trạng thái này hiện được liên kết với ít nhất một Tài sản và không thể bị xóa. Vui lòng cập nhật nội dung của bạn để không tham khảo trạng thái này nữa và thử lại.',

    'create' => [
        'error'   => 'Nhãn trạng thái không được tạo, vui lòng thử lại.',
        'success' => 'Nhãn trạng thái được tạo thành công.',
    ],

    'update' => [
        'error'   => 'Nhãn Tình trạng không được cập nhật, xin vui lòng thử lại',
        'success' => 'Nhãn trạng thái được tạo thành công.',
    ],

    'delete' => [
        'confirm'   => 'Bạn có chắc bạn muốn xóa nhãn tình trạng này?',
        'error'   => 'Đã xảy ra sự cố khi xóa Nhãn trạng thái. Vui lòng thử lại.',
        'success' => 'Nhãn Trạng thái đã bị xóa thành công.',
    ],

    'help' => [
        'undeployable'   => 'Những tài sản này không thể gán cho bất cứ ai.',
        'deployable'   => 'These assets can be checked out. Once they are assigned, they will assume a meta status of <i class="fas fa-circle text-blue"></i> <strong>Deployed</strong>.',
        'archived'   => 'Không thể kiểm tra các tài sản này và sẽ chỉ hiển thị trong chế độ xem Thư mục lưu trữ. Điều này hữu ích cho việc giữ lại thông tin về tài sản cho mục đích lịch sử ngân sách nhưng giữ chúng khỏi danh mục tài sản hằng ngày.',
        'pending'   => 'Những tài sản này không thể được gán cho bất cứ ai, thường được sử dụng cho các vật phẩm được sửa chữa, nhưng dự kiến ​​sẽ quay trở lại lưu thông.',
    ],

];
